@@ -1,3 +1,17 @@
+# Copyright 2021 Element Analytics, Inc.
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#     https://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
 """
 Contains general class to inherit from when creating a new api
 client service
@@ -103,7 +117,7 @@ class ApiRequestManager:
         """
         Creates request header
 
-        :param aut_token: x-auth-toben to be included
+        :param aut_token: x-auth-token to be included
         :type aut_token: str
         :param org_id: Org id where the request will be aimed
         :type org_id: int or str
