@@ -1,3 +1,17 @@
+# Copyright 2021 Element Analytics, Inc.
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#     https://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
 """
 Contains methods to interact with Unify datasets api
 """
@@ -151,7 +165,7 @@ class Sources(ApiRequestManager):
 
     def upload_big_dataset(
             self, name, org_id, content, format="csv",
-            convertToParquet="false", encoding='UTF-8',chunks=10000):
+            convert_to_parquet="false", encoding='UTF-8',chunks=10000):
         """
         Upload a dataset through the static route. This method should be used when
         uploading a big file. It will split the file into
@@ -165,8 +179,8 @@ class Sources(ApiRequestManager):
         :type content: str
         :param format: File format. Accepts "CSV" or "TSV"
         :type format: str, optional
-        :param convertToParquet: Flag to convert file to parquet
-        :type convertToParquet: bool, optional
+        :param convert_to_parquet: Flag to convert file to parquet
+        :type convert_to_parquet: bool, optional
         :param encoding: File encoding
         :type encoding: str, optional
         :param chunks: Number of chunks to split the file
@@ -199,7 +213,7 @@ class Sources(ApiRequestManager):
                     org_id=org_id,
                     file_path=path,
                     format=format,
-                    convertToParquet=convertToParquet,
+                    convert_to_parquet=convert_to_parquet,
                     encoding=encoding
                 )
 
@@ -249,7 +263,7 @@ class Sources(ApiRequestManager):
 
     def create_api_data_set(
             self, name, org_id, file_path, format="csv",
-            convertToParquet="false", encoding="UTF-8"):
+            convert_to_parquet="false", encoding="UTF-8"):
         """
         Creates a dataset through the static file route.
 
@@ -261,8 +275,8 @@ class Sources(ApiRequestManager):
         :type file_path: str
         :param format: File format. Accepts "CSV" or "TSV"
         :type format: str, optional
-        :param convertToParquet: Flag to convert to parquet
-        :type convertToParquet: bool, optional
+        :param convert_to_parquet: Flag to convert to parquet
+        :type convert_to_parquet: bool, optional
         :param encoding: Source file encoding
         :type encoding: str, optional
         :return:
@@ -275,7 +289,7 @@ class Sources(ApiRequestManager):
             org_id,
             content,
             format,
-            convertToParquet,
+            convert_to_parquet,
             encoding
         )
 
@@ -285,7 +299,7 @@ class Sources(ApiRequestManager):
             org_id,
             content,
             format="csv",
-            convertToParquet="false",
+            convert_to_parquet="false",
             encoding="UTF-8"):
         """
         Creates a dataset through the static file route.
@@ -298,8 +312,8 @@ class Sources(ApiRequestManager):
         :type content: str
         :param format: Content format. Accepts "CSV" or "TSV"
         :type format: str, optional
-        :param convertToParquet: Flag to convert to parquet
-        :type convertToParquet: bool, optional
+        :param convert_to_parquet: Flag to convert to parquet
+        :type convert_to_parquet: bool, optional
         :param encoding: Content encoding
         :type encoding: str, optional
         :return:
@@ -311,7 +325,7 @@ class Sources(ApiRequestManager):
             org_id=org_id,
             file_data=content,
             format=format,
-            convertToParquet=convertToParquet,
+            convert_to_parquet=convert_to_parquet,
             encoding=encoding
         )
 
@@ -460,7 +474,7 @@ class Sources(ApiRequestManager):
             name=name,
             org_id=org_id,
             file_path=file_path,
-            groupId=group_id,
+            group_id=group_id,
             format=format
         )
 
@@ -478,8 +492,8 @@ class Sources(ApiRequestManager):
         return results
 
     def overwrite_dataset(
-            self, org_id, data_set_id, file_path, groupId=None,
-            format="csv", convertToParquet="false"):
+            self, org_id, data_set_id, file_path, group_id=None,
+            format="csv", convert_to_parquet="false"):
 
         """
         Overwrites the contents of the given dataset with new content.
@@ -490,12 +504,12 @@ class Sources(ApiRequestManager):
         :type data_set_id: str
         :param file_path: Directory file path that contains the data to be appended
         :type file_path: str
-        :param groupId: Group identification that the dataset belongs
-        :type groupId: str, optional
+        :param group_id: Group identification that the dataset belongs
+        :type group_id: str, optional
         :param format: File format. Accepts "CSV" or "TSV"
         :type format: str, optional
-        :param convertToParquet: Flag to convert file to parquet
-        :type convertToParquet: bool, optional
+        :param convert_to_parquet: Flag to convert file to parquet
+        :type convert_to_parquet: bool, optional
         :return:
         """
         response = {}
@@ -511,9 +525,9 @@ class Sources(ApiRequestManager):
             name=name,
             org_id=org_id,
             file_path=file_path,
-            groupId=groupId,
+            group_id=group_id,
             format=format,
-            convertToParquet=convertToParquet
+            convert_to_parquet=convert_to_parquet
         )
 
         response["append"] = self.append_command(
@@ -639,8 +653,8 @@ class Sources(ApiRequestManager):
 
 
     def stage_data(
-            self, name, org_id, file_path, groupId=None, format="csv",
-            convertToParquet="false", encoding='UTF-8', encode=False):
+            self, name, org_id, file_path, group_id=None, format="csv",
+            convert_to_parquet="false", encoding='UTF-8', encode=False):
         """
         Stages data to a given org and group id.
 
@@ -650,12 +664,12 @@ class Sources(ApiRequestManager):
         :type org_id: int or str
         :param file_path: Directory file path with files to be staged
         :type file_path: str
-        :param groupId: Group identification that the dataset belongs
-        :type groupId: str, optional
+        :param group_id: Group identification that the dataset belongs
+        :type group_id: str, optional
         :param format: File format. Accepts "CSV" or "TSV"
         :type format: str, optional
-        :param convertToParquet: Flag to convert to parquet
-        :type convertToParquet: bool, optional
+        :param convert_to_parquet: Flag to convert to parquet
+        :type convert_to_parquet: bool, optional
         :param encoding: Dataset file encoding
         :type encoding: str, optional
         :param encode: Encode the dataset with given encoding
@@ -671,18 +685,18 @@ class Sources(ApiRequestManager):
 
         headers = dict(header.items())
 
-        if groupId is None:
+        if group_id is None:
             payload_data = {
                 "name": repr(name),
-                "convertToParquet": convertToParquet,
+                "convertToParquet": convert_to_parquet,
                 "format": format
             }
         else:
             payload_data = {
                 "name": repr(name),
-                "convertToParquet": convertToParquet,
+                "convertToParquet": convert_to_parquet,
                 "format": format,
-                "groupId": groupId
+                "groupId": group_id
             }
 
         file_data = open(file_path, "r").read().encode(encoding)
@@ -696,8 +710,8 @@ class Sources(ApiRequestManager):
 
         return test_request.content
 
-    def stage_file(self, name, org_id, file_path, groupId=None, format="csv",
-                   convertToParquet="false", encoding='UTF-8', encode=False):
+    def stage_file(self, name, org_id, file_path, group_id=None, format="csv",
+                   convert_to_parquet="false", encoding='UTF-8', encode=False):
         """
         Stage data from file to a given org and group id.
 
@@ -707,12 +721,12 @@ class Sources(ApiRequestManager):
         :type org_id: int or str
         :param file_path: Directory file path with files to be staged
         :type file_path: str
-        :param groupId: Group identification that the dataset belongs
-        :type groupId: str, optional
+        :param group_id: Group identification that the dataset belongs
+        :type group_id: str, optional
         :param format: File format. Accepts "CSV" or "TSV"
         :type format: str, optional
-        :param convertToParquet: Flag to convert to parquet
-        :type convertToParquet: bool, optional
+        :param convert_to_parquet: Flag to convert to parquet
+        :type convert_to_parquet: bool, optional
         :param encoding: Dataset file encoding
         :type encoding: str, optional
         :param encode: Encode the dataset with given encoding
@@ -726,16 +740,16 @@ class Sources(ApiRequestManager):
             name=name,
             org_id=org_id,
             file_data=file_data,
-            groupId=groupId,
+            group_id=group_id,
             format=format,
-            convertToParquet=convertToParquet,
+            convert_to_parquet=convert_to_parquet,
             encoding=encoding,
             encode=encode
         )
 
     def stage_file_with_content(
-            self, name, org_id, file_data, groupId=None,
-            format="csv", convertToParquet="false", encoding='UTF-8', encode=False
+            self, name, org_id, file_data, group_id=None,
+            format="csv", convert_to_parquet="false", encoding='UTF-8', encode=False
     ):
         """
         Stage data from content to a given org and group id.
@@ -746,12 +760,12 @@ class Sources(ApiRequestManager):
         :type org_id: int or str
         :param file_data: Content with data to be staged
         :type file_data: str
-        :param groupId: Group identification that the dataset belongs
-        :type groupId: str, optional
+        :param group_id: Group identification that the dataset belongs
+        :type group_id: str, optional
         :param format: File format. Accepts "CSV" or "TSV"
         :type format: str, optional
-        :param convertToParquet: Flag to convert to parquet.
-        :type convertToParquet: bool, optional
+        :param convert_to_parquet: Flag to convert to parquet.
+        :type convert_to_parquet: bool, optional
         :param encoding: File encoding
         :type encoding: str, optional
         :param encode: Encode the dataset with given encoding
@@ -767,19 +781,19 @@ class Sources(ApiRequestManager):
 
         headers = dict(header.items())
 
-        if groupId is None:
+        if group_id is None:
 
             payload_data = {
                 "name": repr(name),
-                "convertToParquet": convertToParquet,
+                "convertToParquet": convert_to_parquet,
                 "format": format
             }
         else:
             payload_data = {
                 "name": repr(name),
-                "convertToParquet": convertToParquet,
+                "convertToParquet": convert_to_parquet,
                 "format": format,
-                "groupId": groupId
+                "groupId": group_id
             }
 
         test_request = self.session.post(
